@@ -54,11 +54,12 @@ class Index:
         expressions = [f"({expression.get_sql()})" for expression in self.expressions]
         return self.INDEX_CREATE_TEMPLATE.format(
             exists="IF NOT EXISTS " if safe else "",
-            index_name=schema_generator.quote(
-                self.name or schema_generator._generate_index_name("idx", model, expressions)
-            ),
+            index_name=self.index_name(schema_generator, model),
             index_type=f" {self.INDEX_TYPE} ",
             table_name=schema_generator.quote(model._meta.db_table),
             fields=", ".join(expressions),
             extra=self.extra,
         )
+
+    def index_name(self, schema_generator: "BaseSchemaGenerator", model: "Type[Model]"):
+        return self.name or schema_generator._generate_index_name("idx", model, self.fields)
